<?php

namespace GeorgGriesser\WordPress\Feedback_Suite\Forms;

use GeorgGriesser\WordPress\Feedback_Suite\Setting;

class Article_Feedback_Form
{

    private $setting;

    public function __construct($setting)
    {
        $this->setting = $setting;
    }


    public static function render($content)
    {
        return (new self(Setting::get()))->get($content);
    }

    private function get($content)
    {
        if (!self::is_displayed()) {
            return '';
        }

        $template = '
            <div id="feedbackFormWrapper" class="c-article-feedback-form-wrapper" data-api-url="%9$s">
                
                <style>
                    .c-article-feedback-form .c-vote-button {
                        border-color: %3$s;
                    }
                
                </style>
            
                <div id="beforeForm" class="c-article-feedback-form fbsVisible" style="background: %1$s">
                    
                    <span class="c-article-feedback-form__heading" style="color: %2$s">
                        %4$s
                    </span>
                    
                    <span class="c-article-feedback-form__text" style="color: %3$s">
                        %5$s
                    </span>
                    
                    <div class="c-article-feedback-form__votes" style="color: %3$s">
                        %6$s
                    </div>
                
                </div>
                
                <div id="afterForm" class="c-article-feedback-form fbsHidden" style="background: %1$s">
                    
                    <span class="c-article-feedback-form__heading" style="color: %2$s">
                        %7$s
                    </span>
                    
                    <span class="c-article-feedback-form__text" style="color: %3$s">
                        %8$s
                    </span>    
                
                </div>
            
            </div>
        ';

        return $content . sprintf($template,
            $this->setting['backgroundColor'],
            $this->setting['headingColor'],
            $this->setting['textColor'],
            $this->setting['beforeVoteBoxHeading'],
            $this->setting['beforeVoteBoxText'],
            $this->get_vote_buttons($this->setting['selectedVoteType']),
            $this->setting['afterVoteBoxHeading'],
            $this->setting['afterVoteBoxText'],
            get_rest_url()
        );
    }

    private function get_vote_buttons($selected_vote_type)
    {

        $vote_buttons = array(
            'Up and Downvote (Thumbs)' => '
                <span class="c-vote-button c-vote-button--icon" onclick="jump();vote(this)" data-vote-value="10" data-post-id="%1$s" data-vote-code="Like" ><span class="dashicons dashicons-thumbs-up"></span></span>
                <span class="c-vote-button c-vote-button--icon" onclick="jump();vote(this)" data-vote-value="1" data-post-id="%1$s" data-vote-code="Dislike" ><span class="dashicons dashicons-thumbs-down"></span></span>
                ',
            'Rating (Text)' => 'Rating (Text)',
            'Rating (Smileys)' => 'Rating(Smileys)'
        );

        return sprintf($vote_buttons[$selected_vote_type],
            get_the_ID()
        );
    }

    public static function add_stylesheet()
    {
        if (!self::is_displayed()) {
            return;
        }

        wp_register_style('article-feedback', get_feedback_suite_plugin_dir_url('css/article-feedback.css'));
        wp_enqueue_style('article-feedback');

        wp_enqueue_style('dashicons'); // make sure dashicons are enqueued
    }

    public static function add_script()
    {
        if (!self::is_displayed()) {
            return;
        }

        wp_register_script('article-feedback', get_feedback_suite_plugin_dir_url('js/article-feedback.js'));
        wp_enqueue_script('article-feedback');
    }

    public static function is_displayed() {
        if ( is_front_page() || is_home() || is_archive() || is_search() || is_date() || is_author() || is_attachment()) {
            return false;
        }
        return true;
    }
}