<?php

namespace GeorgGriesser\WordPress\Feedback_Suite;

class Api
{

    public static function add_routes()
    {
        Api::add_settings_routes();
        Api::add_article_feedback_votes_routes();
    }

    private static function add_route($namespace, $route, $arguments = array(), $override = false)
    {
        register_rest_route(
            $namespace,
            $route,
            $arguments,
            $override
        );
    }

    public static function is_allowed() {
        if (self::is_developement_environment()) {
            return true;
        }
        return current_user_can('manage_options');
    }

    private static function is_developement_environment()
    {
        if (defined('FEEDBACK_SUITE_DEVELOPMENT')) {
            if(FEEDBACK_SUITE_DEVELOPMENT === true) {
                return true;
            }
        }
        return false;
    }

    static function add_settings_routes()
    {
        Api::add_route(
            'feedback-suite/v1',
            '/settings',
            array(
                array(
                    'methods' => 'GET',
                    'callback' => array('\GeorgGriesser\WordPress\Feedback_Suite\Http\Controllers\Setting_Controller', 'get_item'),
                    'permission_callback' => array('\GeorgGriesser\WordPress\Feedback_Suite\Api', 'is_allowed')
                ),
                array(
                    'methods' => 'POST',
                    'callback' => array('\GeorgGriesser\WordPress\Feedback_Suite\Http\Controllers\Setting_Controller', 'update_item'),
                    'permission_callback' => array('\GeorgGriesser\WordPress\Feedback_Suite\Api', 'is_allowed')
                ),
                array(
                    'methods' => 'DELETE',
                    'callback' => array('\GeorgGriesser\WordPress\Feedback_Suite\Http\Controllers\Setting_Controller', 'delete_item'),
                    'permission_callback' => array('\GeorgGriesser\WordPress\Feedback_Suite\Api', 'is_allowed')
                )
            )
        );
    }

    static function add_article_feedback_votes_routes()
    {
        Api::add_route(
            'feedback-suite/v1',
            '/article-feedback/votes',
            array(
                array(
                    'methods' => 'GET',
                    'callback' => array('\GeorgGriesser\WordPress\Feedback_Suite\Http\Controllers\Article_Feedback\Vote_Controller', 'index'),
                    'permission_callback' => array('\GeorgGriesser\WordPress\Feedback_Suite\Api', 'is_allowed')
                )
            )
        );

        Api::add_route(
            'feedback-suite/v1',
            '/article-feedback/votes/post/(?P<post_id>[0-9]+)',
            array(
                array(
                    'methods' => 'GET',
                    'callback' => array('\GeorgGriesser\WordPress\Feedback_Suite\Http\Controllers\Article_Feedback\Vote_Controller', 'index_of_post'),
                    'permission_callback' => array('\GeorgGriesser\WordPress\Feedback_Suite\Api', 'is_allowed')
                ),
                array(
                    'methods' => 'POST',
                    'callback' => array('\GeorgGriesser\WordPress\Feedback_Suite\Http\Controllers\Article_Feedback\Vote_Controller', 'add'),
                    'permission_callback' => array('\GeorgGriesser\WordPress\Feedback_Suite\Api', 'is_allowed')
                ),
                array(
                    'methods' => 'DELETE',
                    'callback' => array('\GeorgGriesser\WordPress\Feedback_Suite\Http\Controllers\Article_Feedback\Vote_Controller', 'delete_of_post'),
                    'permission_callback' => array('\GeorgGriesser\WordPress\Feedback_Suite\Api', 'is_allowed')
                )
            )
        );
    }
}