<?php

namespace GeorgGriesser\WordPress\Feedback_Suite;

class Setting
{
    const FEEDBACK_SUITE_OPTION_NAME = 'feedback-suite-option';

    public static function get()
    {
        return get_option(self::FEEDBACK_SUITE_OPTION_NAME, self::get_default());

    }

    public static function update($input)
    {
        $input = self::sanitize($input);

        $input = self::merge_into_existing_settings($input);

        return update_option(self::FEEDBACK_SUITE_OPTION_NAME, $input, true);
    }

    public static function delete()
    {
        return delete_option(self::FEEDBACK_SUITE_OPTION_NAME);
    }

    private static function get_default()
    {
        return array(
            'beforeVoteBoxHeading' => 'Did you enjoy reading this article?',
            'beforeVoteBoxText' => 'Your feedback will help us provide great articles and topics. Please take a second to vote down below.',

            'afterVoteBoxHeading' => 'We appreciate your feedback!',
            'afterVoteBoxText' => 'Thanks for helping us improve our articles.',

            'selectedVoteType' => 'Up and Downvote (Thumbs)',

            'backgroundColor' => '#343778',
            'headingColor' => '#ffffff',
            'textColor' => '#eee'
        );
    }

    public static function sanitize($input)
    {
        return array_map("wp_kses_post", $input);
    }

    private static function merge_into_existing_settings($input)
    {
        $existing = self::get();

        return array_merge(
            $existing,
            array_intersect_key($input, $existing)
        );
    }
}