<?php

namespace GeorgGriesser\WordPress\Feedback_Suite;

class Table_Injector
{

    public static function add_posts_table_head($columns)
    {
        $columns['article_feedback'] = 'Article Feedback';
        return $columns;
    }

    public static function add_posts_table_content($column_name, $post_id)
    {
        if ($column_name == 'article_feedback') {

            $votes = Vote::where(array(
                'post_id' => $post_id
            ));

            if (empty($votes)) {
                self::render_posts_table_content(0, 0, 0);
                return;
            }

            $votes_as_array = array_map(function ($vote) {
                return $vote->as_array();
            }, $votes);

            $values = array();
            $vote_counts = array();

            for ($count = 1; $count <= 10; $count++) {
                $vote_counts[$count] = 0;
            }

            foreach ($votes_as_array as $vote) {

                if (empty($vote_counts[$vote['value']])) {
                    $vote_counts[$vote['value']] = 0;
                }
                $vote_counts[$vote['value']] = $vote_counts[$vote['value']] + 1;

                $values[] = $vote['value'];
            }

            $average = array_sum($values) / count($values);

            self::render_posts_table_content($average, $vote_counts[10], $vote_counts[1]);
        }
    }

    private static function render_posts_table_content($average, $count_up_votes, $count_down_votes)
    {
        $template = '
            <div class="posts-table-votes">
                <span class="post_table-votes__average post_table-votes__average--%1$s"> %1$s</span>
                <div class="post_table-votes__detail">
                    <span class="detail">Average rating: <span>%4$s</span></span>
                    <span class="detail">Upvotes: <span>%2$s</span></span>
                    <span class="detail">Downvotes: <span>%3$s</span></span>           
                </div>
            </div>
        ';

        printf($template,
            round($average),
            $count_up_votes,
            $count_down_votes,
            round($average, 1)
        );
    }

    public static function enqueue_admin_css()
    {
        wp_enqueue_style( 'article-feedback-admin', get_feedback_suite_plugin_dir_url('/css/article-feedback-admin.css') );
    }
}