<?php

namespace GeorgGriesser\WordPress\Feedback_Suite;

class Vote
{

    private $id;
    private $post_id;
    private $value;
    private $code;
    private $created_at;

    private function __construct($id = null, $post_id, $value, $code, $created_at = null)
    {
        $this->id = $id;
        $this->post_id = $post_id;
        $this->value = $value;
        $this->code = $code;
        $this->created_at = $created_at;
    }

    public static function create($post_id, $value, $code)
    {
        return new Vote(null, $post_id, $value, $code, null);
    }

    public static function all()
    {
        return Vote::get();
    }

    public static function where($constraints)
    {
        $votes = self::get(
            $constraints
        );

        return $votes;
    }

    public static function find($id)
    {
        $votes = self::get(
            array(
                'id' => $id
            )
        );

        return $votes[0];
    }

    private static function get($contraints = array())
    {
        global $wpdb;

        $select_sql = sprintf('SELECT* FROM %1$s ', Votes_Table::get_table_name());

        $where_sql = 'WHERE 1=1';

        if (!empty($contraints['id'])) {
            $where_sql .= $wpdb->prepare(' AND id=%d ', $contraints['id']);
        }

        if (!empty($contraints['post_id'])) {
            $where_sql .= $wpdb->prepare(' AND post_id=%d ', $contraints['post_id']);
        }

        $votes_as_array = $wpdb->get_results($select_sql . $where_sql);

        return self::convert_database_array_to_vote_objects($votes_as_array);
    }

    public function save()
    {
        global $wpdb;

        $vote_as_array = $this->as_array();

        // Delete null values - use database-tables' defaults instead
        $vote_as_array = array_filter($vote_as_array);

        //Reorder $column_formats to match the order of columns given in $data
        $vote_as_array_keys = array_keys($vote_as_array);
        $column_formats = array_merge(array_flip($vote_as_array_keys), $this->get_table_column_formats());

        $wpdb->insert(Votes_Table::get_table_name(), $vote_as_array, $column_formats);

        return $wpdb->insert_id;
    }

    private static function convert_database_array_to_vote_objects($votes_as_array) {

        return array_map(function ($vote_as_array) {

            return new Vote(
                $vote_as_array->id,
                $vote_as_array->post_id,
                $vote_as_array->value,
                $vote_as_array->code,
                $vote_as_array->created_at
            );
        }, $votes_as_array);
    }

    public function as_array()
    {
        return array(
            'id' => $this->id,
            'post_id' => $this->post_id,
            'value' => $this->value,
            'code' => $this->code,
            'created_at' => $this->created_at
        );
    }

    private function get_table_column_formats()
    {
        return array(
            'id' => '%d',
            'post_id' => '%d',
            'value' => '%d',
            'code' => '%s',
            'created_at' => '%d'
        );
    }
}